/**
 * @param  {Array<T>} elements
 * @returns Map
 */
export function arrayToMap(elements) {
    const ret = {};
    for (const key in elements) {
        if (Object.prototype.hasOwnProperty.call(elements, key)) {
            const element = elements[key];
            ret[element.id] = element;
        }
    }
    return ret;
}
/**
 * @param  {Map<number} elements
 * @returns Map
 */
export function mapToArray(elements) {
    const ret = new Array();
    for (const key in elements) {
        if (Object.prototype.hasOwnProperty.call(elements, key)) {
            const element = elements[key];
            ret.push(element);
        }
    }
    return ret;
}
/**
 *
 * @returns {number} 1 if the keyboard layout is MacOS type, -1 for others, 0 if no physical keyboard.
 */
export const getKeyboardLayoutType = () => {
    if (/(macintosh|macintel|macppc|mac68k|macos)/i.test(navigator.userAgent))
        return 1;
    else if (/win/i.test(navigator.userAgent) ||
        (/linux/i.test(navigator.userAgent) &&
            !/android/i.test(navigator.userAgent)) ||
        /CrOS/i.test(navigator.userAgent))
        return -1;
    else
        return 0;
};
