import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useEffect, useState, useContext, } from "react";
import { SecurityContext } from "./nerdSecurityAgentWrapper";
import { Box, Grid, Tooltip, Typography } from "@mui/joy";
/**
 * NerdSecurityGate
 *
 * @param {propsType & optionals} props component props
 * @returns {ReactElement} NerdSecurityGate
 */
export function NerdSecurityGate(props) {
    const { id, children, childrenType = "component", redirect } = props;
    const securityContext = useContext(SecurityContext);
    const access = securityContext.access;
    const userServices = securityContext.userServices;
    const [hasAccess, setHasAccess] = useState();
    const requiredRoles = access[id];
    const CLICK_TO_COPY = "Click to copy";
    const COPIED = "Copied !";
    const [tooltipText, setTooltipText] = useState(CLICK_TO_COPY);
    /**
     * Copy to clipboard
     *
     * @param {MouseEvent<HTMLSpanElement, MouseEvent>} e Click Event
     * @returns {Promise<void>}
     */
    async function copy(e) {
        if (!navigator.clipboard)
            return;
        const value = e.currentTarget.textContent;
        if (value !== null) {
            await navigator.clipboard.writeText(value);
            setTooltipText(COPIED);
        }
    }
    useEffect(() => {
        const userAccess = securityContext.overwrite
            ? securityContext.overwrite
            : userServices;
        let _hasAccess = false;
        if (Array.isArray(requiredRoles) && requiredRoles.length > 0 && id !== "") {
            if (userAccess) {
                if (userAccess["account"]?.includes("superadmin"))
                    _hasAccess = true;
                let i = 0;
                while (i < requiredRoles.length && !_hasAccess) {
                    const serviceRole = requiredRoles[i];
                    const [service, role] = serviceRole.split(":");
                    if (userAccess[service]?.includes(role)) {
                        _hasAccess = true;
                    }
                    i++;
                }
            }
        }
        else
            _hasAccess = true;
        setHasAccess(_hasAccess);
    }, [userServices, access]);
    useEffect(() => {
        if (hasAccess === false && childrenType === "route") {
            redirect?.();
        }
    }, [hasAccess]);
    if (hasAccess) {
        if (securityContext.highlight && childrenType === "component") {
            return (_jsxs(Box, { sx: {
                    border: "1px rgb(85,175,245) solid",
                    borderRadius: "4px",
                    margin: "3px",
                    backgroundColor: "rgba(85,175,245,0.1)",
                }, children: [_jsx(Grid, { container: true, children: _jsx(Tooltip, { size: "sm", title: tooltipText, children: _jsx(Grid, { sx: {
                                    height: "18px",
                                    maxWidth: "50%",
                                    marginLeft: "auto",
                                    borderBottomLeftRadius: "8px",
                                    backgroundColor: "rgb(85,175,245)",
                                    padding: "0 5px 0 5px",
                                }, children: _jsx(Typography, { onClick: copy, onMouseOver: () => setTooltipText(CLICK_TO_COPY), sx: {
                                        color: "white",
                                        fontSize: "12px",
                                        overflow: "hidden",
                                        whiteSpace: "nowrap",
                                        textOverflow: "ellipsis",
                                    }, children: id }) }) }) }), children] }));
        }
        else
            return _jsx(_Fragment, { children: children });
    }
    else
        return null;
}
